==> moodle-1.5-mysql.tgz: moodle/lang/ko_utf8/workshop.php <==
<?PHP // $Id$ 
      // workshop.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2004101900)


$string['absent'] = '결석';
$string['accumulative'] = '누적';
$string['action'] = '활동';
$string['addacomment'] = '주석(설명)쓰기';
$string['afterdeadline'] = '제출일($a)후에: ';
$string['ago'] = '$a전에';
$string['agreetothisassessment'] = '이 평가에 동의';
$string['allgradeshaveamaximumof'] = '모든 성적은 최대한$a';
$string['allowresubmit'] = '재진술허용';
$string['alreadyinphase'] = ' $a는 이미 실행되었습니다. ';
$string['amendassessmentelements'] = '평가요소수정';
$string['amendtitle'] = '표제수정하기';
$string['analysis'] = '분석';
$string['analysisofassessments'] = '평가분석';
$string['assess'] = '평가';
$string['assessedon'] = '$a는평가중';
$string['assessment'] = '성적평가';
$string['assessmentby'] = '$a로부터평가';
$string['assessmentdropped'] = '시험에낙제';
$string['assessmentgrade'] = '평가점수: $a';
$string['assessmentnotyetagreed'] = '성적으로 아직 인정되지 않았습니다';
$string['assessmentnotyetgraded'] = '성적채점이 아직 되지 않았습니다';
$string['assessmentofthissubmission'] = '이의견에 대한 평가';
$string['assessments'] = '성적평가';
$string['assessmentsareok'] = '성적평가OK';
$string['assessmentsby'] = '$a로부터평가';
$string['assessmentsdone'] = '평가완료';
$string['assessmentsexcluded'] = '$a를 제외한 평가의 수';
$string['assessmentsmustbeagreed'] = '평가에 동의해야합니다 .';
$string['assessmentwasagreedon'] = '평가가 $a에 동의 되었습니다.';
$string['assessor'] = '평가인';
$string['assessthissubmission'] = '이 제안을 평가';
$string['assignmentnotinthecorrectphase'] = '과제의 관점이 맞지 않습니다';
$string['attachment'] = '첨부';
$string['attachments'] = '첨부';
$string['authorofsubmission'] = '제안자';
$string['averageerror'] = '평균에러';
$string['awaitinggradingbyteacher'] = '$a로부터성적이나올때까지기다리기 ';
$string['beforedeadline'] = '제출일($a)전에';
$string['calculationoffinalgrades'] = '기말성적계산';
$string['closeassignment'] = '과재물완료';
$string['comment'] = '논평';
$string['commentby'] = '로부터논평';
$string['comparisonofassessments'] = '비교평가';
$string['confirmdeletionofthisitem'] = '$a의삭제획인';
$string['correct'] = '교정하다';
$string['count'] = '계산하다';
$string['criterion'] = '표준';
$string['deadline'] = '마감일';
$string['deadlineis'] = '마감일은$a';
$string['delete'] = '삭제하다';
$string['deleting'] = '삭제';
$string['description'] = '설명서';
$string['detailsofassessment'] = '평가의 세부사항';
$string['disagreewiththisassessment'] = '이 평가에 동의하지않기';
$string['displayoffinalgrades'] = '최종학점의 표시';
$string['dontshowgrades'] = '학점을 표시안함';
$string['edit'] = '수정';
$string['editacomment'] = '의견을 수정';
$string['editingassessmentelements'] = '평가요소를 수정';
$string['editsubmission'] = '제안을 수정';
$string['element'] = '요소';
$string['elementweight'] = '중요요소';
$string['enterpassword'] = '비밀번호입력';
$string['errorbanded'] = '에러금지';
$string['errortable'] = '에러목록';
$string['excellent'] = '훌륭한';
$string['excludingdroppedassessments'] = '낙제한 평가를 제외';
$string['expectederror'] = '$a을추측하면 에러가 예상된다';
$string['fair'] = '공평한';
$string['feedbackgoeshere'] = '의견은여기로';
$string['generalcomment'] = '논평';
$string['good'] = '뛰어난';
$string['grade'] = '성적';
$string['gradeassessment'] = '성적평가';
$string['graded'] = '성적평가된';
$string['gradedbyteacher'] = ' $a로부터성적평가';
$string['gradeforassessments'] = '시험성적';
$string['gradeforbias'] = '평가경향';
$string['gradeforreliability'] = '신뢰도';
$string['gradeforstudentsassessment'] = '학생평가성적';
$string['gradeforsubmission'] = '제안에관한성적';
$string['gradegiventoassessment'] = '평가에따른성적';
$string['gradeofsubmission'] = '$a제안에 관한 성적';
$string['gradesforassessmentsare'] = '평가 성적은$a로 부터 ';
$string['gradesforstudentsassessment'] = '$a의 평가에 관한 성적';
$string['gradesforsubmissionsare'] = '의견 성적은 $a로 부터 ';
$string['gradetable'] = '성적표';
$string['gradingallassessments'] = '모든 평가성적';
$string['gradinggrade'] = '성적평가성적';
$string['gradingstrategy'] = '성적평가전술';
$string['hidegradesbeforeagreement'] = '동의하기전에는 성적을 숨김';
$string['hidenamesfromstudents'] = '$a로부터 이름을 숨김';
$string['includeteachersgrade'] = '선생의 성적을 숨김';
$string['incorrect'] = '틀린';
$string['iteration'] = '$a 반복 완료';
$string['lax'] = '애매한';
$string['leaguetable'] = '제출물의 언어표';
$string['listassessments'] = '평가목록';
$string['listofallsubmissions'] = '모든제안의 목록';
$string['liststudentsassessments'] = '학생 평가 목록';
$string['loadingforteacherassessments'] = '$a평가를 불러오기';
$string['mail1'] = '당신의 \'$a\'과제는 평가되었습니다';
$string['mail10'] = '당신의 작업장과제에서 당신은 그것을 평가할수있습니다';
$string['mail2'] = '의견과 성적은 작업장 \'$a\' 과제에서 볼수있습니다';
$string['mail3'] = '당신은 작업장과제에서 그것을 볼수있습니다';
$string['mail4'] = '\'$a\'과제에 의견이 추가되었습니다';
$string['mail5'] = '작업장과제 \'$a\'에서 새로운 의견을 볼수있습니다';
$string['managingassignment'] = '과제를 관리하기';
$string['maximum'] = '최대';
$string['maximumsize'] = '최대크기';
$string['mean'] = '의미';
$string['minimum'] = '최소';
$string['modulename'] = '작업장';
$string['modulenameplural'] = '작업장';
$string['movingtophase'] = '$a관점으로 이동합니다';
$string['namesnotshowntostudents'] = '$a에게 이름을 안보입니다';
$string['newassessments'] = '새로운 평가';
$string['newattachment'] = '새로운 추가사항';
$string['newgradings'] = '새로운 등급';
$string['newsubmissions'] = '새로운 제안';
$string['noassessments'] = '평가없음';
$string['noassessmentsdone'] = '완료된 평가없음';
$string['noattachments'] = '추가사항없음';
$string['nosubmission'] = '제안없음';
$string['nosubmissionsavailableforassessment'] = '평가에대한제안없음';
$string['notavailable'] = '불가능한';
$string['notenoughexamplessubmitted'] = '충분한 예가 제출되지 않았습니다';
$string['noteonstudentassessments'] = '{학생에 의한 평가 / 평가성적평가하기}';
$string['notgraded'] = '점수처리되지않은';
$string['notitle'] = '제목없음';
$string['notitlegiven'] = '제목이 없습니다';
$string['numberofassessments'] = '평가수';
$string['numberofassessmentschanged'] = '평가수 변화$a';
$string['numberofassessmentsdropped'] = '평가수감소$a';
$string['numberofassessmentsofstudentsubmissions'] = '학생의견의 평가수';
$string['numberofassessmentsofteachersexamples'] = '교수지정표본 평가수';
$string['numberofassessmentsweighted'] = '평가수(중요도)$a';
$string['numberofattachments'] = '의견에 따른 첨부물수 제안';
$string['numberofentries'] = '입력건수';
$string['numberofnegativeresponses'] = '부정적의견의수';
$string['numberofsubmissions'] = '제안의수:$a';
$string['on'] = '$a 에';
$string['openassignment'] = '평가열기';
$string['optionaladjustment'] = '선택적인 수정';
$string['optionforpeergrade'] = '같은 성적에 관한 사항';
$string['optionsusedinanalysis'] = '분석에 사용된 사항';
$string['overallgrade'] = '총점';
$string['overallocation'] = '배분초과';
$string['overallpeergrade'] = '전체개인점수$a';
$string['overallteachergrade'] = '전체교수점수$a';
$string['ownwork'] = '자신의작품';
$string['passwordprotectedworkshop'] = '비밀번호로 제한된 작업';
$string['percentageofassessments'] = '드롭한 평가의 백분율';
$string['phase'] = '조정하다';
$string['phase1'] = '과제물은 정하다';
$string['phase1short'] = '정하다';
$string['phase2'] = '$a라는 의견을 받아들이다';
$string['phase2short'] = '의견';
$string['phase3'] = '$a라는 의견과 평가를 받아들이다';
$string['phase3short'] = '둘다';
$string['phase4'] = '$a라는 평가를 받아들이다';
$string['phase4short'] = '평가';
$string['phase5'] = '최후성적공시';
$string['phase5short'] = '성적공시';
$string['poor'] = '형편없는';
$string['present'] = '출석한';
$string['reasonforadjustment'] = '수정이유';
$string['reassess'] = '재평가';
$string['regradestudentassessments'] = '학생평가 점수재평가 ';
$string['removeallattachments'] = '모든 첨부물 지우기';
$string['repeatanalysis'] = '재분석(해석)';
$string['reply'] = '답하다';
$string['returnto'] = '로돌려보내다';
$string['returntosubmissionpage'] = '의견페이지로 돌려보내다';
$string['rubric'] = '주의사항';
$string['savedok'] = '저장완료';
$string['saveleaguetableoptions'] = '언어표옵션저장';
$string['savemyassessment'] = '나의평가저장';
$string['savemycomment'] = '나의논평저장';
$string['savemygrading'] = '나의점수저장';
$string['savemysubmission'] = '나의의견저장';
$string['saveoverallocation'] = '초과배분등급저장';
$string['scale10'] = '10점만점';
$string['scale100'] = '100점만점';
$string['scale20'] = '20점만점';
$string['scalecorrect'] = '2점척도';
$string['scaleexcellent4'] = '4점척도';
$string['scaleexcellent5'] = '5점척도';
$string['scaleexcellent7'] = '7점척도';
$string['scalegood3'] = '3점척도';
$string['scalepresent'] = '출석/결석척도';
$string['scaleyes'] = '예/아니요 척도';
$string['select'] = '선택';
$string['selfassessment'] = '자기평가';
$string['showgrades'] = '성적열람';
$string['specimenassessmentform'] = '평가예제';
$string['standarddeviation'] = '표준편차';
$string['strict'] = '엄격한';
$string['studentassessments'] = '$a평가';
$string['studentgrades'] = '$a의 성적';
$string['studentsubmissions'] = '$a의 의견';
$string['studentsubmissionsforassessment'] = '$a라는 평가에 관한 학생의 의견';
$string['submission'] = '의견';
$string['submissions'] = '의견들';
$string['submissionsnolongerallowed'] = '더이상의 의견은 인정 않됨';
$string['submissionsused'] = '이 표에 이용된 $a라는 의견';
$string['submitassignment'] = '과제물제출';
$string['submitassignmentusingform'] = '이 양식을 이용하여 과제물 제출';
$string['submitexampleassignment'] = '의견의 예를 제출';
$string['submitted'] = '제출';
$string['submittedby'] = '가 제출하다';
$string['suggestedgrade'] = '성적제안';
$string['teacherassessments'] = '평가$a';
$string['teacherscomment'] = '선생의 의견';
$string['teachersgrade'] = '선생의 성적';
$string['teachersubmissionsforassessment'] = '평가에 대한 교사의 의견$a';
$string['thegradeforthisassessmentis'] = '이 평가에 관한 성적은 $a입니다';
$string['thegradeis'] = '성적은$a';
$string['theseasessmentsaregradedbytheteacher'] = '이 평가는 $a에의해 성적매겨졌습니다';
$string['thisisadroppedassessment'] = '이것은 낙제한 평가입니다';
$string['timeassessed'] = '시간평가';
$string['title'] = '주제';
$string['typeofscale'] = '척도유형';
$string['ungradedassessments'] = '성적계산이 되지않은 평가$a';
$string['ungradedassessmentsofstudentsubmissions'] = '성적계산이 되지 않은 학생평가 제안';
$string['ungradedassessmentsofteachersubmissions'] = '성적계산이 되지 않은 교사 평가 제안';
$string['uploadsuccess'] = '업로드성공';
$string['usepassword'] = '패스워드를 사용하시오';
$string['verylax'] = '매우느슨한';
$string['verypoor'] = '매우형편없는';
$string['verystrict'] = '매우엄격한';
$string['view'] = '관점';
$string['viewassessmentofteacher'] = '$a의평가관점';
$string['viewotherassessments'] = '다른평가관점';
$string['warningonamendingelements'] = '이곳의 평가제안이 있으니 숫자나 스케일, 중요요소를 바꾸지 마시오';
$string['weight'] = '중요함';
$string['weightederrorcount'] = '중요에러수:$a';
$string['weightforbias'] = '경향의비중';
$string['weightforgradingofassessments'] = '시험성적계산의중요성';
$string['weightforpeerassessments'] = '응시시험의중요성';
$string['weightforreliability'] = '신뢰의 중요성';
$string['weightforteacherassessments'] = '교사평가의중요성';
$string['weights'] = '영향력';
$string['weightsusedforfinalgrade'] = '기말성적의영향력';
$string['weightsusedforsubmissions'] = '제안들의 영향력';
$string['workshopagreedassessments'] = '인정된평가작업';
$string['workshopassessments'] = '평가작업';
$string['workshopcomments'] = '논평작업';
$string['workshopfeedback'] = '피드백작업';
$string['workshopsubmissions'] = '제안작업';
$string['wrongpassword'] = '이작업을위한잘못된패스워드';
$string['yourassessments'] = '당신의평가';
$string['yourassessmentsofexamplesfromtheteacher'] = '$a에서 당신 평가의 예';
$string['yourfeedbackgoeshere'] = '당신의 반응은여기로';

?>

==> moodle-1.5.3-mysql.tgz: moodle/lang/ko_utf8/workshop.php <==
<?PHP // $Id$ 
      // workshop.php - created with Moodle 1.6 development (2005060201)


$string['absent'] = '결석';
$string['accumulative'] = '누적';
$string['action'] = '활동';
$string['addacomment'] = '주석(설명)쓰기';
$string['addcomment'] = '논평쓰기';
$string['afterdeadline'] = '제출일 후에: $a';
$string['ago'] = '$a 전에';
$string['agrade'] = '성적평가<br />성적';
$string['agreetothisassessment'] = '이 평가에 동의';
$string['allgradeshaveamaximumof'] = '모든 성적은 최대한$a';
$string['allowresubmit'] = '재진술허용';
$string['allsubmissions'] = '모든 부탁,의뢰';
$string['alreadyinphase'] = '$a는 이미 실행되었습니다. ';
$string['amendassessmentelements'] = '평가요소수정';
$string['amendtitle'] = '표제수정하기';
$string['analysis'] = '분석';
$string['analysisofassessments'] = '평가분석';
$string['assess'] = '평가';
$string['assessedon'] = '$a는평가중';
$string['assessment'] = '성적평가';
$string['assessmentby'] = '$a로부터평가';
$string['assessmentdropped'] = '시험에낙제';
$string['assessmentend'] = '마지막 학업평가';
$string['assessmentendevent'] = '$a를 위한 마지막 학업평가';
$string['assessmentgrade'] = '평가점수: $a';
$string['assessmentnotyetagreed'] = '성적으로 아직 인정되지 않았습니다';
$string['assessmentnotyetgraded'] = '성적채점이 아직 되지 않았습니다';
$string['assessmentof'] = '$a의 성적평가';
$string['assessmentofresubmission'] = '이것은 수정된 업무의 성적평가입니다.<br />여기 있는 양식에 당신의 성적과 설명을 미리 채워주십시오.<br />수정된 업무를 잘 살펴보고 개정해주시기 바랍니다.';
$string['assessmentofthissubmission'] = '이의견에 대한 평가';
$string['assessments'] = '성적평가';
$string['assessmentsareok'] = '성적평가OK';
$string['assessmentsby'] = '$a로부터평가';
$string['assessmentsdone'] = '평가완료';
$string['assessmentsexcluded'] = '$a를 제외한 평가의 수';
$string['assessmentsmustbeagreed'] = '평가에 동의해야합니다 .';
$string['assessmentstart'] = '평가의 시작';
$string['assessmentstartevent'] = '$a를 위한 평가의 시작';
$string['assessmentwasagreedon'] = '평가가 $a에 동의 되었습니다.';
$string['assessor'] = '평가인';
$string['assessthisassessment'] = '평가를 성적매기다';
$string['assessthissubmission'] = '이 제안을 평가';
$string['assignmentnotinthecorrectphase'] = '과제의 관점이 맞지 않습니다';
$string['assmnts'] = '성적평가';
$string['attachment'] = '첨부';
$string['attachments'] = '첨부';
$string['authorofsubmission'] = '제안자';
$string['automaticgradeforassessment'] = '성적평가를 위한 자동 평가';
$string['averageerror'] = '평균에러';
$string['awaitinggradingbyteacher'] = '$a로부터성적이나올때까지기다리기 ';
$string['beforedeadline'] = '제출일($a)전에';
$string['by'] = '제출마감';
$string['calculationoffinalgrades'] = '기말성적계산';
$string['clearlateflag'] = '늦게까지있는 깃발을 내리시오';
$string['closeassignment'] = '과재물완료';
$string['comment'] = '논평';
$string['commentbank'] = '논평은행';
$string['commentby'] = '로부터논평';
$string['comparisonofassessments'] = '비교평가';
$string['confirmdeletionofthisitem'] = '$a의삭제획인';
$string['correct'] = '교정하다';
$string['count'] = '계산하다';
$string['criterion'] = '표준';
$string['currentphase'] = '문단흐름';
$string['date'] = '날짜';
$string['datestr'] = '%%d/%%m/%%y<br />%%H:%%M';
$string['deadline'] = '마감일';
$string['deadlineis'] = '마감일은$a';
$string['delete'] = '삭제하다';
$string['deleting'] = '삭제';
$string['description'] = '설명서';
$string['detailsofassessment'] = '평가의 세부사항';
$string['disagreewiththisassessment'] = '이 평가에 동의하지않기';
$string['displayofcurrentgrades'] = '현재성적의 표시';
$string['displayoffinalgrades'] = '최종학점의 표시';
$string['displayofgrades'] = '성적표시';
$string['dontshowgrades'] = '학점을 표시안함';
$string['edit'] = '수정';
$string['editacomment'] = '의견을 수정';
$string['editingassessmentelements'] = '평가요소를 수정';
$string['editsubmission'] = '제안을 수정';
$string['element'] = '요소';
$string['elementweight'] = '중요요소';
$string['enterpassword'] = '비밀번호입력';
$string['errorbanded'] = '에러금지';
$string['errortable'] = '에러목록';
$string['examplesubmissions'] = '제출예시';
$string['excellent'] = '훌륭한';
$string['excludingdroppedassessments'] = '낙제한 평가를 제외';
$string['expectederror'] = '$a을추측하면 에러가 예상된다';
$string['fair'] = '공평한';
$string['feedbackgoeshere'] = '의견은여기로';
$string['firstname'] = '이름';
$string['generalcomment'] = '논평';
$string['good'] = '뛰어난';
$string['grade'] = '성적';
$string['gradeassessment'] = '성적평가';
$string['graded'] = '성적평가된';
$string['gradedbyteacher'] = ' $a로부터성적평가';
$string['gradeforassessments'] = '시험성적';
$string['gradeforbias'] = '평가경향';
$string['gradeforreliability'] = '신뢰도';
$string['gradeforstudentsassessment'] = '학생평가성적';
$string['gradeforsubmission'] = '제안에관한성적';
$string['gradegiventoassessment'] = '평가에따른성적';
$string['gradeofsubmission'] = '$a제안에 관한 성적';
$string['grades'] = '성적';
$string['gradesforassessmentsare'] = '평가 성적은$a로 부터 ';
$string['gradesforstudentsassessment'] = '$a의 평가에 관한 성적';
$string['gradesforsubmissionsare'] = '의견 성적은 $a로 부터 ';
$string['gradetable'] = '성적표';
$string['gradingallassessments'] = '모든 평가성적';
$string['gradinggrade'] = '성적평가성적';
$string['gradingstrategy'] = '성적평가전술';
$string['hidegradesbeforeagreement'] = '동의하기전에는 성적을 숨김';
$string['hidenamesfromstudents'] = '$a로부터 이름을 숨김';
$string['includeteachersgrade'] = '선생의 성적을 숨김';
$string['incorrect'] = '틀린';
$string['info'] = '정보';
$string['invaliddates'] = '당신이 들어간 날짜는 불가능합니다.<br />정확한 날짜와 형식을 갖추기 위해 에 있는 버튼을 사용하십시오.';
$string['iteration'] = '$a 반복 완료';
$string['lastname'] = '성';
$string['lax'] = '애매한';
$string['leaguetable'] = '제출물의 언어표';
$string['listassessments'] = '평가목록';
$string['listofallsubmissions'] = '모든제안의 목록';
$string['liststudentsassessments'] = '학생 평가 목록';
$string['loadingforteacherassessments'] = '$a평가를 불러오기';
$string['mail1'] = '당신의 \'$a\'과제는 평가되었습니다';
$string['mail10'] = '당신의 작업장과제에서 당신은 그것을 평가할수있습니다';
$string['mail2'] = '의견과 성적은 작업장 \'$a\' 과제에서 볼수있습니다';
$string['mail3'] = '당신은 작업장과제에서 그것을 볼수있습니다';
$string['mail4'] = '\'$a\'과제에 의견이 추가되었습니다';
$string['mail5'] = '작업장과제 \'$a\'에서 새로운 의견을 볼수있습니다';
$string['mail6'] = '당신의 과제에 대한 평가 \'$a\'지금까지 재검토되었습니다.';
$string['mail7'] = '과제 $a에 의해 주어진 설명은 업무에 보여질 수 있습니다. ';
$string['mail8'] = '$a과제는 업무의 개정된 일부입니다.';
$string['mail9'] = '$a과제의 모임에 대해 평가해주십시오';
$string['managingassignment'] = '과제를 관리하기';
$string['maximum'] = '최대';
$string['maximumsize'] = '최대크기';
$string['mean'] = '의미';
$string['minimum'] = '최소';
$string['modulename'] = '작업장';
$string['modulenameplural'] = '작업장';
$string['movingtophase'] = '$a관점으로 이동합니다';
$string['namesnotshowntostudents'] = '$a에게 이름을 안보입니다';
$string['newassessments'] = '새로운 평가';
$string['newattachment'] = '새로운 추가사항';
$string['newgradings'] = '새로운 등급';
$string['newsubmissions'] = '새로운 제안';
$string['noassessments'] = '평가없음';
$string['noassessmentsdone'] = '완료된 평가없음';
$string['noattachments'] = '추가사항없음';
$string['nosubmission'] = '제안없음';
$string['nosubmissionsavailableforassessment'] = '평가에대한제안없음';
$string['notallowed'] = '지금 이 페이지는 허락되지 않습니다.';
$string['notavailable'] = '불가능한';
$string['notenoughexamplessubmitted'] = '충분한 예가 제출되지 않았습니다';
$string['noteonassessmentelements'] = '숫자로 나누어진 성적평가 요소에 대해 언급하겠습니다.<br />
이것은 성적을 보다 쉽고 일관되게 만듭니다. 당신이 선생님이라면 반드시 학생들에게 숙제를 내기 전에 이 요소를 설정하십시오.<br /> 
이것은 교육과정의 숙제를 클릭했을때 완료됩니다.<br /> 
만약 이 요소가 설정되지 않았다면 프로그램을 요소 설정으로 바꾸십시오. <br />
당신은 숙제 화면의 숫자구성을 바꿀수 있고 이 구성요소 자신이 성적평가 화면으로 부터 수정됩니다.';
$string['noteonstudentassessments'] = '{학생에 의한 평가 / 평가성적평가하기}';
$string['notgraded'] = '점수처리되지않은';
$string['notitle'] = '제목없음';
$string['notitlegiven'] = '제목이 없습니다';
$string['notsubmittedyet'] = '지금까지 제출한 것이 없습니다.';
$string['nowork'] = '제출기간이 지금 만료되었습니다.<br />당신은 아무 업무도 제출하지 않았습니다.';
$string['numberofassessmentelements'] = '설명의 갯수, 성적평가의 요인, 성적의 굴레, 주석에 있는 평가기준의 설명이나 범주';
$string['numberofassessments'] = '평가수';
$string['numberofassessmentschanged'] = '평가수 변화$a';
$string['numberofassessmentsdropped'] = '평가수감소$a';
$string['numberofassessmentsofstudentsubmissions'] = '학생의견의 평가수';
$string['numberofassessmentsofteachersexamples'] = '교수지정표본 평가수';
$string['numberofassessmentsweighted'] = '평가수(중요도)$a';
$string['numberofattachments'] = '의견에 따른 첨부물수 제안';
$string['numberofentries'] = '입력건수';
$string['numberofnegativeresponses'] = '부정적의견의수';
$string['numberofsubmissions'] = '제안의수:$a';
$string['ograde'] = '총점<br />성적';
$string['on'] = '$a 에';
$string['openassignment'] = '평가열기';
$string['optionaladjustment'] = '선택적인 수정';
$string['optionforpeergrade'] = '같은 성적에 관한 사항';
$string['optionsusedinanalysis'] = '분석에 사용된 사항';
$string['overallgrade'] = '총점';
$string['overallocation'] = '배분초과';
$string['overallpeergrade'] = '전체개인점수$a';
$string['overallteachergrade'] = '전체교수점수$a';
$string['ownwork'] = '자신의작품';
$string['passmnts'] = '공동작업<br />평가';
$string['passwordprotectedworkshop'] = '비밀번호로 제한된 작업';
$string['percentageofassessments'] = '드롭한 평가의 백분율';
$string['phase'] = '조정하다';
$string['phase0'] = '비활동적인';
$string['phase0short'] = '비활동적인';
$string['phase1'] = '과제물은 정하다';
$string['phase1short'] = '정하다';
$string['phase2'] = '$a라는 의견을 받아들이다';
$string['phase2short'] = '의견';
$string['phase3'] = '$a라는 의견과 평가를 받아들이다';
$string['phase3short'] = '둘다';
$string['phase4'] = '$a라는 평가를 받아들이다';
$string['phase4short'] = '평가';
$string['phase5'] = '최후성적공시';
$string['phase5short'] = '성적공시';
$string['pleaseassesstheseexamplesfromtheteacher'] = '$a로부터의 이 예시들을 평가해주십시오.';
$string['pleaseassessthesestudentsubmissions'] = '이 $a제출에 대한 평가를 해주십시오';
$string['pleaseassessyoursubmissions'] = '당신이 제출한 것들을 평가해주십시오';
$string['poor'] = '형편없는';
$string['present'] = '출석한';
$string['reasonforadjustment'] = '수정이유';
$string['reassess'] = '재평가';
$string['regradestudentassessments'] = '학생평가 점수재평가 ';
$string['releaseteachergrades'] = '교사평가를 보여주기';
$string['removeallattachments'] = '모든 첨부물 지우기';
$string['repeatanalysis'] = '재분석(해석)';
$string['reply'] = '답하다';
$string['returnto'] = '로돌려보내다';
$string['returntosubmissionpage'] = '의견페이지로 돌려보내다';
$string['rubric'] = '주의사항';
$string['savedok'] = '저장완료';
$string['saveleaguetableoptions'] = '언어표옵션저장';
$string['savemyassessment'] = '나의평가저장';
$string['savemycomment'] = '나의논평저장';
$string['savemygrading'] = '나의점수저장';
$string['savemysubmission'] = '나의의견저장';
$string['saveoverallocation'] = '초과배분등급저장';
$string['scale10'] = '10점만점';
$string['scale100'] = '100점만점';
$string['scale20'] = '20점만점';
$string['scalecorrect'] = '2점척도';
$string['scaleexcellent4'] = '4점척도';
$string['scaleexcellent5'] = '5점척도';
$string['scaleexcellent7'] = '7점척도';
$string['scalegood3'] = '3점척도';
$string['scalepresent'] = '출석/결석척도';
$string['scaleyes'] = '예/아니요 척도';
$string['select'] = '선택';
$string['selfassessment'] = '자기평가';
$string['sgrade'] = 'Sbmsn<br />성적';
$string['showdescription'] = '활동묘사보여주기';
$string['showgrades'] = '성적열람';
$string['showsubmission'] = '부활동보여주기:$a';
$string['specimenassessmentform'] = '평가예제';
$string['standarddeviation'] = '표준편차';
$string['standarddeviationnote'] = '거의 없거나 매우 작은 가치의 표준적 일탈과의 요소들은 분석을 왜곡할 수 있다. ';
$string['standarddeviationofelement'] = '성분요소$a의 표준일탈';
$string['strict'] = '엄격한';
$string['studentassessments'] = '$a평가';
$string['studentgrades'] = '$a의 성적';
$string['studentsubmissions'] = '$a의 의견';
$string['studentsubmissionsforassessment'] = '$a라는 평가에 관한 학생의 의견';
$string['submission'] = '의견';
$string['submissionend'] = '의견들의 마지막';
$string['submissionendevent'] = '$a를 위한 의견들의 마지막';
$string['submissions'] = '의견들';
$string['submissionsnolongerallowed'] = '더이상의 의견은 인정 않됨';
$string['submissionstart'] = '의견들의 시작';
$string['submissionstartevent'] = '$a를 위한 의견의 시작';
$string['submissionsused'] = '이 표에 이용된 $a라는 의견';
$string['submitassignment'] = '과제물제출';
$string['submitassignmentusingform'] = '이 양식을 이용하여 과제물 제출';
$string['submitexample'] = '예시제출';
$string['submitexampleassignment'] = '의견의 예를 제출';
$string['submitrevisedassignment'] = '이 형식에 사용되는 당신의 개정된 과제를 제출해주십시오';
$string['submitted'] = '제출';
$string['submittedby'] = '가 제출하다';
$string['suggestedgrade'] = '성적제안';
$string['tassmnt'] = '선생<br />평가';
$string['teacherassessments'] = '평가$a';
$string['teachergradeforassessment'] = '성적에 대한 평가$a';
$string['teacherscomment'] = '선생의 의견';
$string['teachersgrade'] = '선생의 성적';
$string['teachersubmissionsforassessment'] = '평가에 대한 교사의 의견$a';
$string['thegradeforthisassessmentis'] = '이 평가에 관한 성적은 $a입니다';
$string['thegradeis'] = '성적은$a';
$string['theseasessmentsaregradedbytheteacher'] = '이 평가는 $a에의해 성적매겨졌습니다';
$string['thisisadroppedassessment'] = '이것은 낙제한 평가입니다';
$string['timeassessed'] = '시간평가';
$string['title'] = '주제';
$string['typeofscale'] = '척도유형';
$string['unassessed'] = '자기힘으로 스스로 하는';
$string['ungradedassessments'] = '성적계산이 되지않은 평가$a';
$string['ungradedassessmentsofstudentsubmissions'] = '성적계산이 되지 않은 학생평가 제안';
$string['ungradedassessmentsofteachersubmissions'] = '성적계산이 되지 않은 교사 평가 제안';
$string['uploadsuccess'] = '업로드성공';
$string['usepassword'] = '패스워드를 사용하시오';
$string['verylax'] = '매우느슨한';
$string['verypoor'] = '매우형편없는';
$string['verystrict'] = '매우엄격한';
$string['view'] = '관점';
$string['viewassessment'] = '제출관점';
$string['viewassessmentofteacher'] = '$a의평가관점';
$string['viewotherassessments'] = '다른평가관점';
$string['warningonamendingelements'] = '이곳의 평가제안이 있으니 숫자나 스케일, 중요요소를 바꾸지 마시오';
$string['weight'] = '중요함';
$string['weightederrorcount'] = '중요에러수:$a';
$string['weightforbias'] = '경향의비중';
$string['weightforgradingofassessments'] = '시험성적계산의중요성';
$string['weightforpeerassessments'] = '응시시험의중요성';
$string['weightforreliability'] = '신뢰의 중요성';
$string['weightforteacherassessments'] = '교사평가의중요성';
$string['weights'] = '영향력';
$string['weightsusedforfinalgrade'] = '기말성적의영향력';
$string['weightsusedforsubmissions'] = '제안들의 영향력';
$string['workshopagreedassessments'] = '인정된평가작업';
$string['workshopassessments'] = '평가작업';
$string['workshopcomments'] = '논평작업';
$string['workshopfeedback'] = '피드백작업';
$string['workshopsubmissions'] = '제안작업';
$string['wrongpassword'] = '이작업을위한잘못된패스워드';
$string['yourassessments'] = '당신의평가';
$string['yourassessmentsofexamplesfromtheteacher'] = '$a에서 당신 평가의 예';
$string['yourfeedbackgoeshere'] = '당신의 반응은여기로';
$string['yoursubmissions'] = '당신의 제출들';

?>
